diff --git a/src/views/HomeView.vue b/src/views/HomeView.vue
index 0e0d13bb1..7e83081d7 100644
--- a/src/views/HomeView.vue
+++ b/src/views/HomeView.vue
@@ -103,7 +103,7 @@
-
+
diff --git a/test-playwright/40-add-contact.spec.ts b/test-playwright/40-add-contact.spec.ts
index 2bb52d697..ede62601c 100644
--- a/test-playwright/40-add-contact.spec.ts
+++ b/test-playwright/40-add-contact.spec.ts
@@ -30,8 +30,9 @@ test('Add contact', async ({ page }) => {
await page.getByPlaceholder('Name', { exact: true }).fill('Contact 00');
await page.locator('.dialog > .flex > button').first().click();
// Confirm that home feed shows contact
await page.goto('./');
+ await expect(page.locator('#sectionRecordSomethingGiven ul li').filter({ hasText: 'Contact 00' }).nth(0)).toBeVisible();
await expect(page.locator('ul#listLatestActivity li').filter({ hasText: 'Contact 00 gave to' }).nth(0)).toBeVisible();
await expect(page.locator('ul#listLatestActivity li').filter({ hasText: 'Contact 00 received' }).nth(0)).toBeVisible();
});
@@ -30,8 +30,9 @@ test('Add contact', async ({ page }) => {
await page.getByPlaceholder('Name', { exact: true }).fill('Contact 00');
await page.locator('.dialog > .flex > button').first().click();
- // Confirm that home feed shows contact
+ // Confirm that home shows contact in "Record Something…" and "Latest Activity"
await page.goto('./');
\ No newline at end of file